@@ -16,9 +16,9 @@ use ArrayIterator;
 use InvalidArgumentException;
 use IteratorAggregate;
 use Predis\Command\CommandInterface;
+use Predis\Command\Container\ContainerFactory;
+use Predis\Command\Container\ContainerInterface;
 use Predis\Command\RawCommand;
-use Predis\Command\Redis\Container\ContainerFactory;
-use Predis\Command\Redis\Container\ContainerInterface;
 use Predis\Command\ScriptCommand;
 use Predis\Configuration\Options;
 use Predis\Configuration\OptionsInterface;
@@ -26,14 +26,15 @@ use Predis\Connection\ConnectionInterface;
 use Predis\Connection\Parameters;
 use Predis\Connection\ParametersInterface;
 use Predis\Connection\RelayConnection;
+use Predis\Consumer\PubSub\Consumer as PubSubConsumer;
+use Predis\Consumer\PubSub\RelayConsumer as RelayPubSubConsumer;
+use Predis\Consumer\Push\Consumer as PushConsumer;
 use Predis\Monitor\Consumer as MonitorConsumer;
 use Predis\Pipeline\Atomic;
 use Predis\Pipeline\FireAndForget;
 use Predis\Pipeline\Pipeline;
 use Predis\Pipeline\RelayAtomic;
 use Predis\Pipeline\RelayPipeline;
-use Predis\PubSub\Consumer as PubSubConsumer;
-use Predis\PubSub\RelayConsumer as RelayPubSubConsumer;
 use Predis\Response\ErrorInterface as ErrorResponseInterface;
 use Predis\Response\ResponseInterface;
 use Predis\Response\ServerException;
@@ -53,7 +54,7 @@ use Traversable;
  */
 class Client implements ClientInterface, IteratorAggregate
 {
-    public const VERSION = '2.4.1';
+    public const VERSION = '3.3.0';
 
     /** @var OptionsInterface */
     private $options;
@@ -379,6 +380,7 @@ class Client implements ClientInterface, IteratorAggregate
     public function executeCommand(CommandInterface $command)
     {
         $response = $this->connection->executeCommand($command);
+        $parameters = $this->connection->getParameters();
 
         if ($response instanceof ResponseInterface) {
             if ($response instanceof ErrorResponseInterface) {
@@ -388,7 +390,11 @@ class Client implements ClientInterface, IteratorAggregate
             return $response;
         }
 
-        return $command->parseResponse($response);
+        if ($parameters->protocol === 2) {
+            return $command->parseResponse($response);
+        }
+
+        return $command->parseResp3Response($response);
     }
 
     /**
@@ -549,6 +555,17 @@ class Client implements ClientInterface, IteratorAggregate
         return $this->sharedContextFactory('createPubSub', func_get_args());
     }
 
+    /**
+     * Creates new push notifications consumer.
+     *
+     * @param  callable|null $preLoopCallback Callback that should be called on client before enter a loop.
+     * @return PushConsumer
+     */
+    public function push(?callable $preLoopCallback = null): PushConsumer
+    {
+        return new PushConsumer($this, $preLoopCallback);
+    }
+
     /**
      * Actual publish/subscribe context initializer method.
      *
