@@ -19,6 +19,7 @@ use Predis\Command\Argument\Search\AlterArguments;
 use Predis\Command\Argument\Search\CreateArguments;
 use Predis\Command\Argument\Search\DropArguments;
 use Predis\Command\Argument\Search\ExplainArguments;
+use Predis\Command\Argument\Search\HybridSearch\HybridSearchQuery;
 use Predis\Command\Argument\Search\ProfileArguments;
 use Predis\Command\Argument\Search\SchemaFields\FieldInterface;
 use Predis\Command\Argument\Search\SearchArguments;
@@ -38,15 +39,16 @@ use Predis\Command\Argument\TimeSeries\MGetArguments;
 use Predis\Command\Argument\TimeSeries\MRangeArguments;
 use Predis\Command\Argument\TimeSeries\RangeArguments;
 use Predis\Command\CommandInterface;
+use Predis\Command\Container\ACL;
+use Predis\Command\Container\CLIENT;
+use Predis\Command\Container\FUNCTIONS;
+use Predis\Command\Container\Json\JSONDEBUG;
+use Predis\Command\Container\Search\FTCONFIG;
+use Predis\Command\Container\Search\FTCURSOR;
+use Predis\Command\Container\XGROUP;
+use Predis\Command\Container\XINFO;
 use Predis\Command\FactoryInterface;
-use Predis\Command\Redis\Container\ACL;
-use Predis\Command\Redis\Container\CLUSTER;
-use Predis\Command\Redis\Container\FunctionContainer;
-use Predis\Command\Redis\Container\Json\JSONDEBUG;
-use Predis\Command\Redis\Container\Search\FTCONFIG;
-use Predis\Command\Redis\Container\Search\FTCURSOR;
-use Predis\Command\Redis\HGETEX;
-use Predis\Command\Redis\HSETEX;
+use Predis\Command\Redis\VADD;
 use Predis\Configuration\OptionsInterface;
 use Predis\Connection\ConnectionInterface;
 use Predis\Response\Status;
@@ -61,6 +63,8 @@ use Predis\Response\Status;
  *
  * @method int               copy(string $source, string $destination, int $db = -1, bool $replace = false)
  * @method int               del(string[]|string $keyOrKeys, string ...$keys = null)
+ * @method int               delex(string $key, string $flag, $flagValue)
+ * @method string            digest(string $key)
  * @method string|null       dump(string $key)
  * @method int               exists(string $key)
  * @method int               expire(string $key, int $seconds, string $expireOption = '')
@@ -70,8 +74,8 @@ use Predis\Response\Status;
  * @method int               move(string $key, int $db)
  * @method mixed             object($subcommand, string $key)
  * @method int               persist(string $key)
- * @method int               pexpire(string $key, int $milliseconds)
- * @method int               pexpireat(string $key, int $timestamp)
+ * @method int               pexpire(string $key, int $milliseconds, string $option = null)
+ * @method int               pexpireat(string $key, int $timestamp, string $option = null)
  * @method int               pttl(string $key)
  * @method string|null       randomkey()
  * @method mixed             rename(string $key, string $target)
@@ -82,8 +86,8 @@ use Predis\Response\Status;
  * @method int               ttl(string $key)
  * @method mixed             type(string $key)
  * @method int               append(string $key, $value)
- * @method int               bfadd(string $key, $item)
- * @method int               bfexists(string $key, $item)
+ * @method mixed             bfadd(string $key, $item)
+ * @method mixed             bfexists(string $key, $item)
  * @method array             bfinfo(string $key, string $modifier = '')
  * @method array             bfinsert(string $key, int $capacity = -1, float $error = -1, int $expansion = -1, bool $noCreate = false, bool $nonScaling = false, string ...$item)
  * @method Status            bfloadchunk(string $key, int $iterator, $data)
@@ -100,11 +104,11 @@ use Predis\Response\Status;
  * @method array             bzpopmax(array $keys, int $timeout)
  * @method array             bzpopmin(array $keys, int $timeout)
  * @method array             bzmpop(int $timeout, array $keys, string $modifier = 'min', int $count = 1)
- * @method int               cfadd(string $key, $item)
- * @method int               cfaddnx(string $key, $item)
+ * @method mixed             cfadd(string $key, $item)
+ * @method mixed             cfaddnx(string $key, $item)
  * @method int               cfcount(string $key, $item)
- * @method int               cfdel(string $key, $item)
- * @method int               cfexists(string $key, $item)
+ * @method mixed             cfdel(string $key, $item)
+ * @method mixed             cfexists(string $key, $item)
  * @method Status            cfloadchunk(string $key, int $iterator, $data)
  * @method int               cfmexists(string $key, ...$item)
  * @method array             cfinfo(string $key)
@@ -135,6 +139,7 @@ use Predis\Response\Status;
  * @method array             ftdictdump(string $dict)
  * @method Status            ftdropindex(string $index, ?DropArguments $arguments = null)
  * @method string            ftexplain(string $index, string $query, ?ExplainArguments $arguments = null)
+ * @method array             fthybrid(string $index, HybridSearchQuery $query)
  * @method array             ftinfo(string $index)
  * @method array             ftprofile(string $index, ProfileArguments $arguments)
  * @method array             ftsearch(string $index, string $query, ?SearchArguments $arguments = null)
@@ -157,9 +162,10 @@ use Predis\Response\Status;
  * @method string            incrbyfloat(string $key, int|float $increment)
  * @method array             mget(string[]|string $keyOrKeys, string ...$keys = null)
  * @method mixed             mset(array $dictionary)
+ * @method array             msetex(array $dictionary, ?string $existModifier = null, ?string $expireResolution = null, ?int $expireTTL = null)
  * @method int               msetnx(array $dictionary)
  * @method Status            psetex(string $key, $milliseconds, $value)
- * @method Status|null       set(string $key, $value, $expireResolution = null, $expireTTL = null, $flag = null)
+ * @method Status|null       set(string $key, $value, $expireResolution = null, $expireTTL = null, $flag = null, $flagValue = null)
  * @method int               setbit(string $key, $offset, $value)
  * @method Status            setex(string $key, $seconds, $value)
  * @method int               setnx(string $key, $value)
@@ -202,8 +208,8 @@ use Predis\Response\Status;
  * @method array             jsonarrtrim(string $key, string $path, int $start, int $stop)
  * @method int               jsondel(string $key, string $path = '$')
  * @method int               jsonforget(string $key, string $path = '$')
- * @method string            jsonget(string $key, string $indent = '', string $newline = '', string $space = '', string ...$paths)
- * @method string            jsonnumincrby(string $key, string $path, int $value)
+ * @method mixed             jsonget(string $key, string $indent = '', string $newline = '', string $space = '', string ...$paths)
+ * @method mixed             jsonnumincrby(string $key, string $path, int $value)
  * @method Status            jsonmerge(string $key, string $path, string $value)
  * @method array             jsonmget(array $keys, string $path)
  * @method Status            jsonmset(string ...$keyPathValue)
@@ -250,9 +256,12 @@ use Predis\Response\Status;
  * @method string|array|null spop(string $key, ?int $count = null)
  * @method string|null       srandmember(string $key, ?int $count = null)
  * @method int               srem(string $key, array|string $member)
- * @method array             sscan(string $key, int $cursor, ?array $options = null)
+ * @method array             sscan(string $key, int $cursor, array $options = null)
+ * @method array             ssubscribe(string ...$shardChannels)
+ * @method array             subscribe(string ...$channels)
  * @method string[]          sunion(array|string $keys)
  * @method int               sunionstore(string $destination, array|string $keys)
+ * @method array             sunsubscribe(?string ...$shardChannels = null)
  * @method int               touch(string[]|string $keyOrKeys, string ...$keys = null)
  * @method Status            tdigestadd(string $key, float ...$value)
  * @method array             tdigestbyrank(string $key, int ...$rank)
@@ -260,10 +269,10 @@ use Predis\Response\Status;
  * @method array             tdigestcdf(string $key, int ...$value)
  * @method Status            tdigestcreate(string $key, int $compression = 0)
  * @method array             tdigestinfo(string $key)
- * @method string            tdigestmax(string $key)
+ * @method mixed             tdigestmax(string $key)
  * @method Status            tdigestmerge(string $destinationKey, array $sourceKeys, int $compression = 0, bool $override = false)
  * @method string[]          tdigestquantile(string $key, float ...$quantile)
- * @method string            tdigestmin(string $key)
+ * @method mixed             tdigestmin(string $key)
  * @method array             tdigestrank(string $key, float ...$value)
  * @method Status            tdigestreset(string $key)
  * @method array             tdigestrevrank(string $key, float ...$value)
@@ -291,13 +300,22 @@ use Predis\Response\Status;
  * @method array             tsqueryindex(string ...$filterExpression)
  * @method array             tsrange(string $key, $fromTimestamp, $toTimestamp, ?RangeArguments $arguments = null)
  * @method array             tsrevrange(string $key, $fromTimestamp, $toTimestamp, ?RangeArguments $arguments = null)
- * @method string            xadd(string $key, array $dictionary, string $id = '*', ?array $options = null)
+ * @method int               xack(string $key, string $group, string ...$id)
+ * @method array             xackdel(string $key, string $group, string $mode, array $ids)
+ * @method string            xadd(string $key, array $dictionary, string $id = '*', array $options = null)
+ * @method array             xautoclaim(string $key, string $group, string $consumer, int $minIdleTime, string $start, ?int $count = null, bool $justId = false)
+ * @method array             xclaim(string $key, string $group, string $consumer, int $minIdleTime, string|array $ids, ?int $idle = null, ?int $time = null, ?int $retryCount = null, bool $force = false, bool $justId = false, ?string $lastId = null)
  * @method int               xdel(string $key, string ...$id)
+ * @method array             xdelex(string $key, string $mode, array $ids)
  * @method int               xlen(string $key)
+ * @method array             xpending(string $key, string $group, ?int $minIdleTime = null, ?string $start = null, ?string $end = null, ?int $count = null, ?string $consumer = null)
  * @method array             xrevrange(string $key, string $end, string $start, ?int $count = null)
  * @method array             xrange(string $key, string $start, string $end, ?int $count = null)
- * @method string            xtrim(string $key, array|string $strategy, string $threshold, ?array $options = null)
  * @method array|null        xread(int $count = null, int $block = null, array $streams = null, string ...$id)
+ * @method array             xreadgroup(string $group, string $consumer, ?int $count = null, ?int $blockMs = null, bool $noAck = false, string ...$keyOrId)
+ * @method array             xreadgroup_claim(string $group, string $consumer, array $keyIdDict, ?int $count = null, ?int $blockMs = null, bool $noAck = false, ?int $claim = null)
+ * @method Status            xsetid(string $key, string $lastId, ?int $entriesAdded = null, ?string $maxDeleteId = null)
+ * @method string            xtrim(string $key, array|string $strategy, string $threshold, array $options = null)
  * @method int               zadd(string $key, array $membersAndScoresDictionary)
  * @method int               zcard(string $key)
  * @method int               zcount(string $key, int|string $min, int|string $max)
@@ -340,6 +358,18 @@ use Predis\Response\Status;
  * @method array|null        exec()
  * @method mixed             multi()
  * @method mixed             unwatch()
+ * @method array             unsubscribe(string ...$channels)
+ * @method bool              vadd(string $key, string|array $vector, string $elem, int $dim = null, bool $cas = false, string $quant = VADD::QUANT_DEFAULT, int $bef = null, string|array $attributes = null, int $numlinks = null)
+ * @method int               vcard(string $key)
+ * @method int               vdim(string $key)
+ * @method array             vemb(string $key, string $elem, bool $raw = false)
+ * @method string|array|null vgetattr(string $key, string $elem, bool $asJson = false)
+ * @method array|null        vinfo(string $key)
+ * @method array|null        vlinks(string $key, string $elem, bool $withScores = false)
+ * @method string|array|null vrandmember(string $key, int $count = null)
+ * @method bool              vrem(string $key, string $elem)
+ * @method array             vsim(string $key, string|array $vectorOrElem, bool $isElem = false, bool $withScores = false, int $count = null, float $epsilon = null, int $ef = null, string $filter = null, int $filterEf = null, bool $truth = false, bool $noThread = false)
+ * @method bool              vsetattr(string $key, string $elem, string|array $attributes)
  * @method array             waitaof(int $numLocal, int $numReplicas, int $timeout)
  * @method mixed             watch(string[]|string $keyOrKeys)
  * @method mixed             eval(string $script, int $numkeys, string ...$keyOrArg = null)
@@ -354,18 +384,18 @@ use Predis\Response\Status;
  * @method mixed             select(int $database)
  * @method mixed             bgrewriteaof()
  * @method mixed             bgsave()
- * @method mixed             client($subcommand, $argument = null)
  * @method mixed             config($subcommand, $argument = null)
  * @method int               dbsize()
  * @method mixed             flushall()
  * @method mixed             flushdb()
- * @method array             info($section = null)
+ * @method array             info(string ...$section = null)
  * @method int               lastsave()
  * @method mixed             save()
  * @method mixed             slaveof(string $host, int $port)
  * @method mixed             slowlog($subcommand, $argument = null)
+ * @method int               spublish(string $shardChannel, string $message)
  * @method array             time()
- * @method array             command()
+ * @method array             command($subcommand, $argument = null)
  * @method int               geoadd(string $key, $longitude, $latitude, $member)
  * @method array             geohash(string $key, array $members)
  * @method array             geopos(string $key, array $members)
@@ -376,14 +406,14 @@ use Predis\Response\Status;
  * @method int               geosearchstore(string $destination, string $source, FromInterface $from, ByInterface $by, ?string $sorting = null, int $count = -1, bool $any = false, bool $storeDist = false)
  *
  * Container commands
- * @property CLUSTER           $cluster
- * @property FunctionContainer $function
- * @property FTCONFIG          $ftconfig
- * @property FTCURSOR          $ftcursor
- * @property JSONDEBUG         $jsondebug
- * @property ACL               $acl
- *
- * @no-named-arguments
+ * @property CLIENT    $client
+ * @property FUNCTIONS $function
+ * @property FTCONFIG  $ftconfig
+ * @property FTCURSOR  $ftcursor
+ * @property JSONDEBUG $jsondebug
+ * @property ACL       $acl
+ * @property XGROUP    $xgroup
+ * @property XINFO     $xinfo
  */
 interface ClientInterface
 {
