@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 
 /**
  * @see http://redis.io/commands/sdiff
@@ -36,4 +36,9 @@ class SDIFF extends RedisCommand
 
         parent::setArguments($arguments);
     }
+
+    public function prefixKeys($prefix)
+    {
+        $this->applyPrefixForAllArguments($prefix);
+    }
 }
