@@ -87,6 +87,18 @@ class ACL_Test extends PredisCommandTestCase
         $this->assertEquals('OK', $redis->acl->setUser('Test'));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testSetUserResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $this->assertEquals('OK', $redis->acl->setUser('Test'));
+    }
+
     /**
      * @group connected
      * @return void
@@ -107,6 +119,22 @@ class ACL_Test extends PredisCommandTestCase
         );
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisVersion >= 7.0.0
+     */
+    public function testDryRunResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $this->assertEquals('OK', $redis->acl->setUser('Test', '+SET', '~*'));
+        $this->assertEquals(
+            'OK',
+            $redis->acl->dryRun('Test', 'SET', 'foo', 'bar')
+        );
+    }
+
     /**
      * @group connected
      * @return void
@@ -301,6 +329,32 @@ class ACL_Test extends PredisCommandTestCase
         $this->assertEquals(1, $redis->tsadd('test', time(), 0.01));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisVersion >= 6.0.0
+     */
+    public function testGetUserResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $this->assertEquals(
+            'OK',
+            $redis->acl->setUser(
+                'alan',
+                'allkeys',
+                '+@string',
+                '+@set',
+                '-SADD',
+                '>alanpassword'
+            )
+        );
+
+        foreach (['flags', 'passwords', 'commands', 'keys', 'channels'] as $key) {
+            $this->assertArrayHasKey($key, $redis->acl->getUser('alan'));
+        }
+    }
+
     /**
      * @group connected
      * @return void
