@@ -12,6 +12,7 @@
 
 namespace Predis\Command\Redis\Json;
 
+use Predis\Command\PrefixableCommand;
 use Predis\Command\Redis\PredisCommandTestCase;
 use UnexpectedValueException;
 
@@ -57,6 +58,23 @@ class JSONSET_Test extends PredisCommandTestCase
         $this->assertSame(1, $this->getCommand()->parseResponse(1));
     }
 
+    /**
+     * @group disconnected
+     */
+    public function testPrefixKeys(): void
+    {
+        /** @var PrefixableCommand $command */
+        $command = $this->getCommand();
+        $actualArguments = ['arg1'];
+        $prefix = 'prefix:';
+        $expectedArguments = ['prefix:arg1'];
+
+        $command->setArguments($actualArguments);
+        $command->prefixKeys($prefix);
+
+        $this->assertSame($expectedArguments, $command->getArguments());
+    }
+
     /**
      * @group connected
      * @group relay-resp3
