@@ -100,6 +100,19 @@ class FTCONFIG_Test extends PredisCommandTestCase
         $this->assertEquals('OK', $redis->ftconfig->set('TIMEOUT', 42));
     }
 
+    /**
+     * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRedisVersion <= 7.0.0
+     */
+    public function testSetGivenRediSearchConfigurationParameterResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $this->assertEquals('OK', $redis->ftconfig->set('TIMEOUT', 42));
+    }
+
     /**
      * @group connected
      * @group relay-resp3
@@ -114,6 +127,20 @@ class FTCONFIG_Test extends PredisCommandTestCase
         $this->assertEmpty($redis->ftconfig->get('foobar'));
     }
 
+    /**
+     * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRediSearchVersion >= 2.8.0
+     */
+    public function testGetReturnsGivenRediSearchConfigurationParameterResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $this->assertEquals(['MAXEXPANSIONS' => '200'], $redis->ftconfig->get('MAXEXPANSIONS'));
+        $this->assertEmpty($redis->ftconfig->get('foobar'));
+    }
+
     /**
      * @group connected
      * @group relay-resp3
