@@ -84,7 +84,6 @@ class FTSUGGET_Test extends PredisCommandTestCase
 
     /**
      * @group connected
-     * @group relay-resp3
      * @return void
      * @requiresRediSearchVersion >= 1.0.0
      */
@@ -100,6 +99,23 @@ class FTSUGGET_Test extends PredisCommandTestCase
         $this->assertSame(['hell'], $actualResponse);
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRediSearchVersion >= 2.8.0
+     */
+    public function testGetReturnsLimitedResultsWithMaxModifierResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->ftsugadd('key', 'hello', 2);
+        $redis->ftsugadd('key', 'hell', 2);
+
+        $actualResponse = $redis->ftsugget('key', 'hel', (new SugGetArguments())->max(1));
+
+        $this->assertSame(['hell'], $actualResponse);
+    }
+
     /**
      * @group connected
      * @return void
