@@ -13,6 +13,7 @@
 namespace Predis\Monitor;
 
 use Predis\Client;
+use Predis\Connection\Parameters;
 use Predis\Monitor\Consumer as MonitorConsumer;
 use PredisTestCase;
 
@@ -92,6 +93,11 @@ class ConsumerTest extends PredisTestCase
     {
         $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         /** @var \Predis\ClientInterface */
         $client = $this->getMockBuilder('Predis\Client')
             ->onlyMethods(['disconnect'])
@@ -113,6 +119,11 @@ class ConsumerTest extends PredisTestCase
     {
         $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         /** @var \Predis\ClientInterface */
         $client = $this->getMockBuilder('Predis\Client')
             ->onlyMethods(['disconnect'])
@@ -140,6 +151,11 @@ class ConsumerTest extends PredisTestCase
             ->method('read')
             ->willReturn($message);
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $client = new Client($connection);
 
         $monitor = new MonitorConsumer($client);
@@ -165,6 +181,11 @@ class ConsumerTest extends PredisTestCase
             ->method('read')
             ->willReturn($message);
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $client = new Client($connection);
 
         $monitor = new MonitorConsumer($client);
@@ -190,6 +211,7 @@ class ConsumerTest extends PredisTestCase
             'host' => constant('REDIS_SERVER_HOST'),
             'port' => constant('REDIS_SERVER_PORT'),
             'database' => constant('REDIS_SERVER_DBNUM'),
+            'password' => getenv('REDIS_PASSWORD') ?: constant('REDIS_PASSWORD'),
             // Prevents suite from handing on broken test
             'read_write_timeout' => 2,
         ];
