@@ -18,7 +18,9 @@ use Predis\Client;
 use Predis\ClientInterface;
 use Predis\Command\CommandInterface;
 use Predis\Connection\NodeConnectionInterface;
+use Predis\Connection\Parameters;
 use Predis\Response;
+use Predis\Transaction\Exception\TransactionException;
 use PredisTestCase;
 use RuntimeException;
 
@@ -780,6 +782,7 @@ class MultiExecTest extends PredisTestCase
 
     /**
      * @group connected
+     * @group relay-incompatible
      * @requiresRedisVersion >= 2.2.0
      */
     public function testIntegrationWritesOnWatchedKeysAbortTransaction(): void
@@ -802,6 +805,31 @@ class MultiExecTest extends PredisTestCase
         $this->assertSame('client2', $client1->get('sentinel'));
     }
 
+    /**
+     * @group connected
+     * @group ext-relay
+     * @requiresRedisVersion >= 2.2.0
+     */
+    public function testRelayIntegrationWritesOnWatchedKeysAbortTransaction(): void
+    {
+        $exception = null;
+        $client1 = $this->getClient();
+        $client2 = $this->getClient();
+
+        try {
+            $client1->transaction(['watch' => 'sentinel'], function ($tx) use ($client2) {
+                $tx->set('sentinel', 'client1');
+                $tx->get('sentinel');
+                $client2->set('sentinel', 'client2');
+            });
+        } catch (Response\ServerException $ex) {
+            $exception = $ex;
+        }
+
+        $this->assertInstanceOf(Response\ServerException::class, $exception);
+        $this->assertSame('client2', $client1->get('sentinel'));
+    }
+
     /**
      * @group connected
      * @requiresRedisVersion >= 2.2.0
@@ -850,6 +878,136 @@ class MultiExecTest extends PredisTestCase
         $this->assertSame([['hijacked!', null]], $responses);
     }
 
+    /**
+     * @group connected
+     * @group cluster
+     * @return void
+     * @requiresRedisVersion >= 3.0.0
+     */
+    public function testExecutesTransactionAgainstCluster(): void
+    {
+        $redis = $this->getClient();
+
+        $response = $redis->transaction(function (MultiExec $tx) {
+            $tx->set('{foo}foo', 'value');
+            $tx->set('{foo}bar', 'value');
+            $tx->set('{foo}baz', 'value');
+        });
+
+        $this->assertEquals(['OK', 'OK', 'OK'], $response);
+    }
+
+    /**
+     * @group connected
+     * @group cluster
+     * @return void
+     * @requiresRedisVersion >= 3.0.0
+     */
+    public function testThrowsExceptionOnDifferentHashSlots(): void
+    {
+        $redis = $this->getClient();
+
+        $this->expectException(AbortedMultiExecException::class);
+        $this->expectExceptionMessage(
+            'To be able to execute a transaction against cluster, all commands should operate on the same hash slot'
+        );
+
+        $redis->transaction(function (MultiExec $tx) {
+            $tx->set('foo_bar_baz', 'value');
+            $tx->set('{foo}bar', 'value');
+            $tx->set('{foo}baz', 'value');
+        });
+    }
+
+    /**
+     * @group connected
+     * @group cluster
+     * @return void
+     * @requiresRedisVersion >= 3.0.0
+     */
+    public function testExecutesCASTransactionAgainstCluster(): void
+    {
+        $redis = $this->getClient();
+        $options = ['cas' => true, 'watch' => ['{foo}foo', '{foo}bar', '{foo}baz']];
+
+        $response = $redis->transaction($options, function (MultiExec $tx) {
+            $tx->multi();
+            $tx->set('{foo}foo', 'value');
+            $tx->set('{foo}bar', 'value');
+            $tx->set('{foo}baz', 'value');
+        });
+
+        $this->assertEquals(['OK', 'OK', 'OK'], $response);
+    }
+
+    /**
+     * @group connected
+     * @group cluster
+     * @return void
+     * @requiresRedisVersion >= 3.0.0
+     */
+    public function testUNWATCHCurrentlyWATCHedKeys(): void
+    {
+        $redis = $this->getClient();
+        $options = ['cas' => true, 'watch' => ['{foo}foo', '{foo}bar', '{foo}baz']];
+
+        $response = $redis->transaction($options, function (MultiExec $tx) {
+            $tx->multi();
+            $tx->set('{foo}foo', 'value');
+            $tx->set('{foo}bar', 'value');
+            $tx->set('{foo}baz', 'value');
+            $tx->unwatch();
+        });
+
+        $this->assertEquals(['OK', 'OK', 'OK', 'OK'], $response);
+    }
+
+    /**
+     * @group connected
+     * @group cluster
+     * @return void
+     * @requiresRedisVersion >= 3.0.0
+     */
+    public function testThrowsExceptionOnWATCHedKeysPointsToDifferentSlots(): void
+    {
+        $redis = $this->getClient();
+        $options = ['cas' => true, 'watch' => ['foo_bar_baz', '{foo}bar', '{foo}baz']];
+
+        $this->expectException(TransactionException::class);
+        $this->expectExceptionMessage('WATCHed keys should point to the same hash slot');
+
+        $redis->transaction($options, function (MultiExec $tx) {
+            $tx->multi();
+            $tx->set('{foo}foo', 'value');
+            $tx->set('{foo}bar', 'value');
+            $tx->set('{foo}baz', 'value');
+        });
+    }
+
+    /**
+     * @group connected
+     * @group cluster
+     * @return void
+     * @requiresRedisVersion >= 3.0.0
+     */
+    public function testThrowsExceptionOnTransactionContextPointsToDifferentSlots(): void
+    {
+        $redis = $this->getClient();
+        $options = ['cas' => true, 'watch' => ['{foo}foo', '{foo}bar', '{foo}baz']];
+
+        $this->expectException(AbortedMultiExecException::class);
+        $this->expectExceptionMessage(
+            'To be able to execute a transaction against cluster, all commands should operate on the same hash slot'
+        );
+
+        $redis->transaction($options, function (MultiExec $tx) {
+            $tx->multi();
+            $tx->set('{foo}foo', 'value');
+            $tx->set('{foo}bar', 'value');
+            $tx->set('foo_bar_baz', 'value');
+        });
+    }
+
     // ******************************************************************** //
     // ---- HELPER METHODS ------------------------------------------------ //
     // ******************************************************************** //
@@ -870,6 +1028,10 @@ class MultiExecTest extends PredisTestCase
             ->method('executeCommand')
             ->willReturnCallback($executeCallback);
 
+        $connection
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         return $connection;
     }
 
@@ -887,6 +1049,11 @@ class MultiExecTest extends PredisTestCase
     protected function getMockedTransaction($executeCallback, $txOpts = null, $clientOpts = null): MultiExec
     {
         $connection = $this->getMockedConnection($executeCallback);
+
+        $connection
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $client = new Client($connection, $clientOpts ?: []);
         $transaction = new MultiExec($client, $txOpts ?: []);
 
